=================
astrometric_utils
=================

The ``astrometric_utils`` module provides functions for generating
astrometric catalogs of sources for the field-of-view covered by a
set of images.

.. currentmodule:: romancal.tweakreg.astrometric_utils

.. automodule:: romancal.tweakreg.astrometric_utils
   :members:
   :undoc-members:
